[svn-commits] mmichelson: branch group/CCSS r213009 - in /team/group/CCSS: channels/ includ...

SVN commits to the Digium repositories svn-commits at lists.digium.com
Tue Aug 18 19:00:30 CDT 2009


Author: mmichelson
Date: Tue Aug 18 19:00:26 2009
New Revision: 213009

URL: http://svn.asterisk.org/svn-view/asterisk?view=rev&rev=213009
Log:
Change all instances of ccss in functions to cc.

CCSS is fine in comments, but interspersing it with cc
in function names and enums and structs and such is
just annoying.


Modified:
    team/group/CCSS/channels/chan_sip.c
    team/group/CCSS/include/asterisk/ccss.h

Modified: team/group/CCSS/channels/chan_sip.c
URL: http://svn.asterisk.org/svn-view/asterisk/team/group/CCSS/channels/chan_sip.c?view=diff&rev=213009&r1=213008&r2=213009
==============================================================================
--- team/group/CCSS/channels/chan_sip.c (original)
+++ team/group/CCSS/channels/chan_sip.c Tue Aug 18 19:00:26 2009
@@ -5121,7 +5121,7 @@
 	dialog->peerauth = peer->auth;
 	dialog->maxcallbitrate = peer->maxcallbitrate;
 	dialog->disallowed_methods = peer->disallowed_methods;
-	ast_ccss_copy_config_params(dialog->cc_params, peer->cc_params);
+	ast_cc_copy_config_params(dialog->cc_params, peer->cc_params);
 	if (ast_strlen_zero(dialog->tohost))
 		ast_string_field_set(dialog, tohost, ast_inet_ntoa(dialog->sa.sin_addr));
 	if (!ast_strlen_zero(peer->fromdomain)) {
@@ -24364,7 +24364,7 @@
 		} else if (!strcasecmp(v->name, "disallowed_methods")) {
 			char *disallow = ast_strdupa(v->value);
 			mark_parsed_methods(&peer->disallowed_methods, disallow);
-		} else if (ast_ccss_is_cc_config_param(v->name)) {
+		} else if (ast_cc_is_config_param(v->name)) {
 			ast_cc_set_param(peer->cc_params, v->name, v->value);
 		}
 	}

Modified: team/group/CCSS/include/asterisk/ccss.h
URL: http://svn.asterisk.org/svn-view/asterisk/team/group/CCSS/include/asterisk/ccss.h?view=diff&rev=213009&r1=213008&r2=213009
==============================================================================
--- team/group/CCSS/include/asterisk/ccss.h (original)
+++ team/group/CCSS/include/asterisk/ccss.h Tue Aug 18 19:00:26 2009
@@ -29,11 +29,11 @@
 
 enum service_type {
 	/* Call Completion Busy Subscriber */
-	AST_CCSS_CCBS,
+	AST_CC_CCBS,
 	/* Call Completion No Response */
-	AST_CCSS_CCNR,
+	AST_CC_CCNR,
 	/* Call Completion Not Logged In (currently SIP only) */
-	AST_CCSS_CCNL,
+	AST_CC_CCNL,
 };
 
 /*!
@@ -42,7 +42,7 @@
  *
  * For more information, see doc/CCSS_architecture.pdf
  */
-enum ast_ccss_state {
+enum ast_cc_state {
 	/*! Entered when it is determined that CCSS may be used for the call */
 	CC_AVAILABLE,
 	/*! Entered when a CCSS agent has offered CCSS to a caller */
@@ -85,33 +85,33 @@
  * \since 1.6.4
  * \brief The various possibilities for cc_agent_policy values
  */
-enum ast_ccss_agent_policies {
+enum ast_cc_agent_policies {
 	/*! Never offer CCSS to the caller */
-	AST_CCSS_AGENT_NEVER,
+	AST_CC_AGENT_NEVER,
 	/*! Offer CCSS using native signaling */
-	AST_CCSS_AGENT_NATIVE,
+	AST_CC_AGENT_NATIVE,
 	/*! Use generic agent for caller */
-	AST_CCSS_AGENT_GENERIC,
+	AST_CC_AGENT_GENERIC,
 };
 
 /*!
  * \since 1.6.4
  * \brief The various possibilities for cc_monitor_policy values
  */
-enum ast_ccss_monitor_policies {
+enum ast_cc_monitor_policies {
 	/*! Never accept CCSS offers from callee */
-	AST_CCSS_MONITOR_NEVER,
+	AST_CC_MONITOR_NEVER,
 	/* CCSS only available if callee offers it through signaling */
-	AST_CCSS_MONITOR_NATIVE,
+	AST_CC_MONITOR_NATIVE,
 	/*! Always use CCSS generic monitor for callee
 	 * Note that if callee offers CCSS natively, we still
 	 * will use a generic CCSS monitor if this is set
 	 */
-	AST_CCSS_MONITOR_GENERIC,
+	AST_CC_MONITOR_GENERIC,
 	/*! Accept native CCSS offers, but if no offer is present,
 	 * use a generic CCSS monitor
 	 */
-	AST_CCSS_MONITOR_ALWAYS,
+	AST_CC_MONITOR_ALWAYS,
 };
 
 /* Forward declaration. Struct is in main/ccss.c */
@@ -157,7 +157,7 @@
  * \retval 1 Yes, this is a CCSS configuration parameter.
  * \retval 0 No, this is not a CCSS configuration parameter.
  */
-int ast_ccss_is_cc_config_param(const char * const name);
+int ast_cc_is_config_param(const char * const name);
 
 /*!
  * \since 1.6.4
@@ -173,7 +173,7 @@
  * \retval -1 Copy failed (no way for this to happen yet)
  * \retval 0 Copy succeeded
  */
-void ast_ccss_copy_config_params(struct ast_cc_config_params *dest, const struct ast_cc_config_params *src);
+void ast_cc_copy_config_params(struct ast_cc_config_params *dest, const struct ast_cc_config_params *src);
 
 /*!
  * \since 1.6.4
@@ -181,7 +181,7 @@
  * \param config The configuration to retrieve the policy from
  * \return The current cc_agent_policy for this configuration
  */
-enum ast_ccss_agent_policies ast_get_cc_agent_policy(struct ast_cc_config_params *config);
+enum ast_cc_agent_policies ast_get_cc_agent_policy(struct ast_cc_config_params *config);
 
 /*!
  * \since 1.6.4
@@ -191,7 +191,7 @@
  * \retval 0 Success
  * \retval -1 Failure (likely due to bad input)
  */
-int ast_set_cc_agent_policy(struct ast_cc_config_params *config, enum ast_ccss_agent_policies value);
+int ast_set_cc_agent_policy(struct ast_cc_config_params *config, enum ast_cc_agent_policies value);
 
 /*!
  * \since 1.6.4
@@ -199,7 +199,7 @@
  * \param config The configuration to retrieve the cc_monitor_policy from
  * \return The cc_monitor_policy retrieved from the configuration
  */
-enum ast_ccss_monitor_policies ast_get_cc_monitor_policy(struct ast_cc_config_params *config);
+enum ast_cc_monitor_policies ast_get_cc_monitor_policy(struct ast_cc_config_params *config);
 
 /*!
  * \since 1.6.4
@@ -209,7 +209,7 @@
  * \retval 0 Success
  * \retval -1 Failure (likely due to bad input)
  */
-int ast_set_cc_monitor_policy(struct ast_cc_config_params *config, enum ast_ccss_monitor_policies value);
+int ast_set_cc_monitor_policy(struct ast_cc_config_params *config, enum ast_cc_monitor_policies value);
 
 /*!
  * \since 1.6.4
@@ -302,7 +302,7 @@
  * \param config The configuration to retrieve the callback_macro from
  * \return The callback_macro name
  */
-const char *ast_get_callback_macro(struct ast_cc_config_params *config);
+const char *ast_get_cc_callback_macro(struct ast_cc_config_params *config);
 
 /*!
  * \since 1.6.4
@@ -321,11 +321,11 @@
  * monitor has no more links pointing to it, it will be automatically 
  * destroyed.
  */
-struct ast_ccss_monitor_link {
+struct ast_cc_monitor_link {
 	/* The parent monitor (always an extension monitor) */
-	struct ast_ccss_monitor *parent;
+	struct ast_cc_monitor *parent;
 	/* The child monitor (may be extension or device monitor) */
-	struct ast_ccss_monitor *child;
+	struct ast_cc_monitor *child;
 	/* The weight associated with this link. Lower weights have higher 
 	 * priority 
 	 */
@@ -339,12 +339,12 @@
 };
 
 /*! Used to determine which type
  * of monitor an ast_ccss_device_monitor
  * is.
  */
-enum ast_ccss_monitor_type {
-	AST_CCSS_DEVICE_MONITOR,
-	AST_CCSS_EXTENSION_MONITOR,
+enum ast_cc_monitor_type {
+	AST_CC_DEVICE_MONITOR,
+	AST_CC_EXTENSION_MONITOR,
 	/* A root monitor is a placeholder type, which serves
 	 * as a central root for a CCSS monitor tree. Its only job
 	 * is to pipe requests it receives from an extension monitor
@@ -354,7 +354,7 @@
 	 *
 	 * XXX This may turn out to not be necessary
 	 */
-	AST_CCSS_ROOT_MONITOR,
+	AST_CC_ROOT_MONITOR,
 };
 
 /*! 
@@ -366,7 +366,7 @@
  * In addition, a device monitor will always be a "leaf" in the tree of
  * CCSS monitors, so they will only have parents, no children.
  */
-struct ast_ccss_device_monitor_data {
+struct ast_cc_device_monitor_data {
 	/*! We need to remember which type of service to request/was requested
 	 * by this specific device monitor so we don't cause problems downstream
 	 */
@@ -379,7 +379,7 @@
 	 * but if a device is dialed by multiple extensions, then it is possible
 	 * to have a list of multiple extension monitors as parents. 
 	 */
-	AST_LIST_HEAD(,ast_ccss_monitor_link) parent_links;
+	AST_LIST_HEAD(,ast_cc_monitor_link) parent_links;
 	/*! Device monitor operations which will vary between implementations. Think
 	 * of this sort of like the ast_channel_tech structure
 	 */
@@ -390,23 +390,23 @@
 	void *private_data;
 };
 
-struct ast_ccss_extension_monitor_data {
+struct ast_cc_extension_monitor_data {
 	/*! List of extensions which have failed outstanding calls to this extension.
 	 * I find it unlikely that this will ever be largely populated. The root monitor
 	 * may also be the sole parent of an extension monitor, which makes this extension
 	 * monitor the "root" of a particular CC tree.
 	 */
-	AST_LIST_HEAD(,ast_ccss_monitor_link) parent_links;
+	AST_LIST_HEAD(,ast_cc_monitor_link) parent_links;
 	/*! List of downstream device monitors. This list will have multiple elements
 	 * in it for extensions which dial multiple devices.
 	 */
-	AST_LIST_HEAD(,ast_ccss_monitor_link) child_links;
+	AST_LIST_HEAD(,ast_cc_monitor_link) child_links;
 	const char *extension;
 	const char *context;
 };
 
-struct ast_ccss_root_monitor_data {
-	AST_LIST_HEAD(,ast_ccss_monitor_link) child_links;
+struct ast_cc_root_monitor_data {
+	AST_LIST_HEAD(,ast_cc_monitor_link) child_links;
 };
 
 /*! 
@@ -415,30 +415,30 @@
  * with this structure. Information specific to each monitor
  * type can be retrieved through the monitor_data union.
  */
-struct ast_ccss_monitor {
+struct ast_cc_monitor {
 	/*! One of CCBS or CCNR. */
-	enum ast_ccss_monitor_type type;
+	enum ast_cc_monitor_type type;
 	/*! There are different types of monitors that each
 	 * need to do their own thing.
 	 */
 	union {
-		struct ast_ccss_device_monitor_data device_data;
-		struct ast_ccss_extension_monitor_data extension_data;
-		struct ast_ccss_root_monitor_data root_data;
+		struct ast_cc_device_monitor_data device_data;
+		struct ast_cc_extension_monitor_data extension_data;
+		struct ast_cc_root_monitor_data root_data;
 	} monitor_data;
 	/*! The name of the device/extension being monitored */
 	const char *name;
 	/*! The list of links to upstream extension monitors */
-	AST_LIST_HEAD(,ast_ccss_monitor_link) parent_links;
+	AST_LIST_HEAD(,ast_cc_monitor_link) parent_links;
 	/*! Callback functions needed for specific device monitor
 	 * implementations
 	 */
-	const struct ast_ccss_device_monitor_callbacks *callbacks;
+	const struct ast_cc_device_monitor_callbacks *callbacks;
 	/*! Data specific to a device monitor implementation */
 	void *private_data;
 };
 
-struct ast_ccss_device_monitor_callbacks {
+struct ast_cc_device_monitor_callbacks {
 	/* Allocate callback */
 	/* Request CCSS callback */
 	/* Suspend monitoring callback */
@@ -447,7 +447,7 @@
 	/* Pass status upstream callback */
 };
 
-struct ast_ccss_agent {
+struct ast_cc_agent {
 	/*! Which instance of the core state machine does this
 	 * agent pertain to?
 	 */
@@ -455,12 +455,12 @@
 	/*! Callback functions needed for specific agent
 	 * implementations
 	 */
-	const struct ast_ccss_agent_callbacks *callbacks;
+	const struct ast_cc_agent_callbacks *callbacks;
 	/*! Data specific to agent implementation */
 	void *private_data;
 };
 
-struct ast_ccss_agent_callbacks {
+struct ast_cc_agent_callbacks {
 	/* Allocate callback */
 	/* Acknowledge CCSS request callback */
 	/* Status request callback */
@@ -479,7 +479,7 @@
  * \retval non-negative The identifier for this instance of the CCSS core
  */
 /*
-int ast_ccss_core_init_instance(const char *caller,  called_tree);
+int ast_cc_core_init_instance(const char *caller,  called_tree);
 */
 
 /*!
@@ -491,6 +491,6 @@
  * \retval 0 State change successfully queued
  * \retval -1 Unable to queue state change request
  */
-int ast_ccss_request_state_change(enum ast_ccss_state state, const unsigned int core_id, const char *debug);
+int ast_cc_request_state_change(enum ast_cc_state state, const unsigned int core_id, const char *debug);
 
 #endif /* _ASTERISK_CCSS_H */
@@ -339,12 +339,12 @@
 
 /*! Used to determine which type
- * of monitor an ast_ccss_device_monitor
+ * of monitor an ast_cc_device_monitor
  * is.
  */




More information about the svn-commits mailing list